@@ -33,7 +33,6 @@ from .literals import (
     TargetFilterNameType,
 )
 from .paginator import (
-    DeploymentSuccessfulWaiter,
     ListApplicationRevisionsPaginator,
     ListApplicationsPaginator,
     ListDeploymentConfigsPaginator,
@@ -97,6 +96,7 @@ from .type_defs import (
     TriggerConfigTypeDef,
     UpdateDeploymentGroupOutputTypeDef,
 )
+from .waiter import DeploymentSuccessfulWaiter
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -233,7 +233,7 @@ class Exceptions:
 
 class CodeDeployClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -244,7 +244,7 @@ class CodeDeployClient:
         self, tags: List["TagTypeDef"], instanceNames: List[str]
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.add_tags_to_on_premises_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.add_tags_to_on_premises_instances)
         [Show boto3-stubs documentation](./client.md#add_tags_to_on_premises_instances)
         """
 
@@ -252,7 +252,7 @@ class CodeDeployClient:
         self, applicationName: str, revisions: List["RevisionLocationTypeDef"]
     ) -> BatchGetApplicationRevisionsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_application_revisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_application_revisions)
         [Show boto3-stubs documentation](./client.md#batch_get_application_revisions)
         """
 
@@ -260,7 +260,7 @@ class CodeDeployClient:
         self, applicationNames: List[str]
     ) -> BatchGetApplicationsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_applications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_applications)
         [Show boto3-stubs documentation](./client.md#batch_get_applications)
         """
 
@@ -268,7 +268,7 @@ class CodeDeployClient:
         self, applicationName: str, deploymentGroupNames: List[str]
     ) -> BatchGetDeploymentGroupsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_groups)
         [Show boto3-stubs documentation](./client.md#batch_get_deployment_groups)
         """
 
@@ -276,7 +276,7 @@ class CodeDeployClient:
         self, deploymentId: str, instanceIds: List[str]
     ) -> BatchGetDeploymentInstancesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_instances)
         [Show boto3-stubs documentation](./client.md#batch_get_deployment_instances)
         """
 
@@ -284,13 +284,13 @@ class CodeDeployClient:
         self, deploymentId: str = None, targetIds: List[str] = None
     ) -> BatchGetDeploymentTargetsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_targets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployment_targets)
         [Show boto3-stubs documentation](./client.md#batch_get_deployment_targets)
         """
 
     def batch_get_deployments(self, deploymentIds: List[str]) -> BatchGetDeploymentsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_deployments)
         [Show boto3-stubs documentation](./client.md#batch_get_deployments)
         """
 
@@ -298,13 +298,13 @@ class CodeDeployClient:
         self, instanceNames: List[str]
     ) -> BatchGetOnPremisesInstancesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_on_premises_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_on_premises_instances)
         [Show boto3-stubs documentation](./client.md#batch_get_on_premises_instances)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.can_paginate)
         [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
@@ -312,7 +312,7 @@ class CodeDeployClient:
         self, deploymentId: str = None, deploymentWaitType: DeploymentWaitTypeType = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.continue_deployment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.continue_deployment)
         [Show boto3-stubs documentation](./client.md#continue_deployment)
         """
 
@@ -323,7 +323,7 @@ class CodeDeployClient:
         tags: List["TagTypeDef"] = None,
     ) -> CreateApplicationOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.create_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.create_application)
         [Show boto3-stubs documentation](./client.md#create_application)
         """
 
@@ -341,7 +341,7 @@ class CodeDeployClient:
         fileExistsBehavior: FileExistsBehaviorType = None,
     ) -> CreateDeploymentOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment)
         [Show boto3-stubs documentation](./client.md#create_deployment)
         """
 
@@ -353,7 +353,7 @@ class CodeDeployClient:
         computePlatform: ComputePlatformType = None,
     ) -> CreateDeploymentConfigOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_config)
         [Show boto3-stubs documentation](./client.md#create_deployment_config)
         """
 
@@ -379,19 +379,19 @@ class CodeDeployClient:
         tags: List["TagTypeDef"] = None,
     ) -> CreateDeploymentGroupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_group)
         [Show boto3-stubs documentation](./client.md#create_deployment_group)
         """
 
     def delete_application(self, applicationName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.delete_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.delete_application)
         [Show boto3-stubs documentation](./client.md#delete_application)
         """
 
     def delete_deployment_config(self, deploymentConfigName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.delete_deployment_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.delete_deployment_config)
         [Show boto3-stubs documentation](./client.md#delete_deployment_config)
         """
 
@@ -399,7 +399,7 @@ class CodeDeployClient:
         self, applicationName: str, deploymentGroupName: str
     ) -> DeleteDeploymentGroupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.delete_deployment_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.delete_deployment_group)
         [Show boto3-stubs documentation](./client.md#delete_deployment_group)
         """
 
@@ -407,19 +407,19 @@ class CodeDeployClient:
         self, tokenName: str = None
     ) -> DeleteGitHubAccountTokenOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.delete_git_hub_account_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.delete_git_hub_account_token)
         [Show boto3-stubs documentation](./client.md#delete_git_hub_account_token)
         """
 
     def delete_resources_by_external_id(self, externalId: str = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.delete_resources_by_external_id)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.delete_resources_by_external_id)
         [Show boto3-stubs documentation](./client.md#delete_resources_by_external_id)
         """
 
     def deregister_on_premises_instance(self, instanceName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.deregister_on_premises_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.deregister_on_premises_instance)
         [Show boto3-stubs documentation](./client.md#deregister_on_premises_instance)
         """
 
@@ -431,13 +431,13 @@ class CodeDeployClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.generate_presigned_url)
         [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_application(self, applicationName: str) -> GetApplicationOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.get_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.get_application)
         [Show boto3-stubs documentation](./client.md#get_application)
         """
 
@@ -445,19 +445,19 @@ class CodeDeployClient:
         self, applicationName: str, revision: "RevisionLocationTypeDef"
     ) -> GetApplicationRevisionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.get_application_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.get_application_revision)
         [Show boto3-stubs documentation](./client.md#get_application_revision)
         """
 
     def get_deployment(self, deploymentId: str) -> GetDeploymentOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment)
         [Show boto3-stubs documentation](./client.md#get_deployment)
         """
 
     def get_deployment_config(self, deploymentConfigName: str) -> GetDeploymentConfigOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_config)
         [Show boto3-stubs documentation](./client.md#get_deployment_config)
         """
 
@@ -465,7 +465,7 @@ class CodeDeployClient:
         self, applicationName: str, deploymentGroupName: str
     ) -> GetDeploymentGroupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_group)
         [Show boto3-stubs documentation](./client.md#get_deployment_group)
         """
 
@@ -473,7 +473,7 @@ class CodeDeployClient:
         self, deploymentId: str, instanceId: str
     ) -> GetDeploymentInstanceOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_instance)
         [Show boto3-stubs documentation](./client.md#get_deployment_instance)
         """
 
@@ -481,13 +481,13 @@ class CodeDeployClient:
         self, deploymentId: str = None, targetId: str = None
     ) -> GetDeploymentTargetOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_target)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.get_deployment_target)
         [Show boto3-stubs documentation](./client.md#get_deployment_target)
         """
 
     def get_on_premises_instance(self, instanceName: str) -> GetOnPremisesInstanceOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.get_on_premises_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.get_on_premises_instance)
         [Show boto3-stubs documentation](./client.md#get_on_premises_instance)
         """
 
@@ -502,19 +502,19 @@ class CodeDeployClient:
         nextToken: str = None,
     ) -> ListApplicationRevisionsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.list_application_revisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.list_application_revisions)
         [Show boto3-stubs documentation](./client.md#list_application_revisions)
         """
 
     def list_applications(self, nextToken: str = None) -> ListApplicationsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.list_applications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.list_applications)
         [Show boto3-stubs documentation](./client.md#list_applications)
         """
 
     def list_deployment_configs(self, nextToken: str = None) -> ListDeploymentConfigsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_configs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_configs)
         [Show boto3-stubs documentation](./client.md#list_deployment_configs)
         """
 
@@ -522,7 +522,7 @@ class CodeDeployClient:
         self, applicationName: str, nextToken: str = None
     ) -> ListDeploymentGroupsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_groups)
         [Show boto3-stubs documentation](./client.md#list_deployment_groups)
         """
 
@@ -534,7 +534,7 @@ class CodeDeployClient:
         instanceTypeFilter: List[InstanceTypeType] = None,
     ) -> ListDeploymentInstancesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_instances)
         [Show boto3-stubs documentation](./client.md#list_deployment_instances)
         """
 
@@ -545,7 +545,7 @@ class CodeDeployClient:
         targetFilters: Dict[TargetFilterNameType, List[str]] = None,
     ) -> ListDeploymentTargetsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_targets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_targets)
         [Show boto3-stubs documentation](./client.md#list_deployment_targets)
         """
 
@@ -559,7 +559,7 @@ class CodeDeployClient:
         nextToken: str = None,
     ) -> ListDeploymentsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.list_deployments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.list_deployments)
         [Show boto3-stubs documentation](./client.md#list_deployments)
         """
 
@@ -567,7 +567,7 @@ class CodeDeployClient:
         self, nextToken: str = None
     ) -> ListGitHubAccountTokenNamesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.list_git_hub_account_token_names)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.list_git_hub_account_token_names)
         [Show boto3-stubs documentation](./client.md#list_git_hub_account_token_names)
         """
 
@@ -578,7 +578,7 @@ class CodeDeployClient:
         nextToken: str = None,
     ) -> ListOnPremisesInstancesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.list_on_premises_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.list_on_premises_instances)
         [Show boto3-stubs documentation](./client.md#list_on_premises_instances)
         """
 
@@ -586,7 +586,7 @@ class CodeDeployClient:
         self, ResourceArn: str, NextToken: str = None
     ) -> ListTagsForResourceOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
@@ -597,7 +597,7 @@ class CodeDeployClient:
         status: LifecycleEventStatusType = None,
     ) -> PutLifecycleEventHookExecutionStatusOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.put_lifecycle_event_hook_execution_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.put_lifecycle_event_hook_execution_status)
         [Show boto3-stubs documentation](./client.md#put_lifecycle_event_hook_execution_status)
         """
 
@@ -605,7 +605,7 @@ class CodeDeployClient:
         self, applicationName: str, revision: "RevisionLocationTypeDef", description: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.register_application_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.register_application_revision)
         [Show boto3-stubs documentation](./client.md#register_application_revision)
         """
 
@@ -613,7 +613,7 @@ class CodeDeployClient:
         self, instanceName: str, iamSessionArn: str = None, iamUserArn: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.register_on_premises_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.register_on_premises_instance)
         [Show boto3-stubs documentation](./client.md#register_on_premises_instance)
         """
 
@@ -621,13 +621,13 @@ class CodeDeployClient:
         self, tags: List["TagTypeDef"], instanceNames: List[str]
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.remove_tags_from_on_premises_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.remove_tags_from_on_premises_instances)
         [Show boto3-stubs documentation](./client.md#remove_tags_from_on_premises_instances)
         """
 
     def skip_wait_time_for_instance_termination(self, deploymentId: str = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.skip_wait_time_for_instance_termination)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.skip_wait_time_for_instance_termination)
         [Show boto3-stubs documentation](./client.md#skip_wait_time_for_instance_termination)
         """
 
@@ -635,19 +635,19 @@ class CodeDeployClient:
         self, deploymentId: str, autoRollbackEnabled: bool = None
     ) -> StopDeploymentOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.stop_deployment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.stop_deployment)
         [Show boto3-stubs documentation](./client.md#stop_deployment)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.tag_resource)
         [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.untag_resource)
         [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
@@ -655,7 +655,7 @@ class CodeDeployClient:
         self, applicationName: str = None, newApplicationName: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.update_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.update_application)
         [Show boto3-stubs documentation](./client.md#update_application)
         """
 
@@ -681,7 +681,7 @@ class CodeDeployClient:
         onPremisesTagSet: "OnPremisesTagSetTypeDef" = None,
     ) -> UpdateDeploymentGroupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Client.update_deployment_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Client.update_deployment_group)
         [Show boto3-stubs documentation](./client.md#update_deployment_group)
         """
 
@@ -690,7 +690,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_application_revisions"]
     ) -> ListApplicationRevisionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)[Show boto3-stubs documentation](./paginators.md#listapplicationrevisionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)[Show boto3-stubs documentation](./paginators.md#listapplicationrevisionspaginator)
         """
 
     @overload
@@ -698,7 +698,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_applications"]
     ) -> ListApplicationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)[Show boto3-stubs documentation](./paginators.md#listapplicationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)[Show boto3-stubs documentation](./paginators.md#listapplicationspaginator)
         """
 
     @overload
@@ -706,7 +706,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployment_configs"]
     ) -> ListDeploymentConfigsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)[Show boto3-stubs documentation](./paginators.md#listdeploymentconfigspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)[Show boto3-stubs documentation](./paginators.md#listdeploymentconfigspaginator)
         """
 
     @overload
@@ -714,7 +714,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployment_groups"]
     ) -> ListDeploymentGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)[Show boto3-stubs documentation](./paginators.md#listdeploymentgroupspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)[Show boto3-stubs documentation](./paginators.md#listdeploymentgroupspaginator)
         """
 
     @overload
@@ -722,7 +722,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployment_instances"]
     ) -> ListDeploymentInstancesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)[Show boto3-stubs documentation](./paginators.md#listdeploymentinstancespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)[Show boto3-stubs documentation](./paginators.md#listdeploymentinstancespaginator)
         """
 
     @overload
@@ -730,7 +730,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployment_targets"]
     ) -> ListDeploymentTargetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)[Show boto3-stubs documentation](./paginators.md#listdeploymenttargetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)[Show boto3-stubs documentation](./paginators.md#listdeploymenttargetspaginator)
         """
 
     @overload
@@ -738,7 +738,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_deployments"]
     ) -> ListDeploymentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)[Show boto3-stubs documentation](./paginators.md#listdeploymentspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)[Show boto3-stubs documentation](./paginators.md#listdeploymentspaginator)
         """
 
     @overload
@@ -746,7 +746,7 @@ class CodeDeployClient:
         self, operation_name: Literal["list_git_hub_account_token_names"]
     ) -> ListGitHubAccountTokenNamesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)[Show boto3-stubs documentation](./paginators.md#listgithubaccounttokennamespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)[Show boto3-stubs documentation](./paginators.md#listgithubaccounttokennamespaginator)
         """
 
     @overload
@@ -754,12 +754,12 @@ class CodeDeployClient:
         self, operation_name: Literal["list_on_premises_instances"]
     ) -> ListOnPremisesInstancesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)[Show boto3-stubs documentation](./paginators.md#listonpremisesinstancespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)[Show boto3-stubs documentation](./paginators.md#listonpremisesinstancespaginator)
         """
 
     def get_waiter(
         self, waiter_name: Literal["deployment_successful"]
     ) -> DeploymentSuccessfulWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codedeploy.html#CodeDeploy.Waiter.deployment_successful)[Show boto3-stubs documentation](./waiters.md#deploymentsuccessfulwaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/codedeploy.html#CodeDeploy.Waiter.deployment_successful)[Show boto3-stubs documentation](./waiters.md#deploymentsuccessfulwaiter)
         """
